summaryrefslogtreecommitdiff
path: root/gst/asfmux
diff options
context:
space:
mode:
authorMark Nauwelaerts <mark.nauwelaerts@collabora.co.uk>2012-04-17 15:22:59 +0200
committerMark Nauwelaerts <mark.nauwelaerts@collabora.co.uk>2012-04-17 15:22:59 +0200
commit65787972455106bff29c37d4ffcde116c33e0fb0 (patch)
tree6ba6467e6985fcf04300992533bef282a232d200 /gst/asfmux
parent156d80d74b4088c39a3d2909bdd91eb494e5abd5 (diff)
downloadgstreamer-plugins-bad-65787972455106bff29c37d4ffcde116c33e0fb0.tar.gz
collectpads2: rename to collectpads
Diffstat (limited to 'gst/asfmux')
-rw-r--r--gst/asfmux/gstasfmux.c28
-rw-r--r--gst/asfmux/gstasfmux.h6
-rw-r--r--gst/asfmux/gstasfobjects.h4
3 files changed, 19 insertions, 19 deletions
diff --git a/gst/asfmux/gstasfmux.h b/gst/asfmux/gstasfmux.h
index 49bd92d8f..4036aa169 100644
--- a/gst/asfmux/gstasfmux.h
+++ b/gst/asfmux/gstasfmux.h
@@ -23,7 +23,7 @@
#include <gst/gst.h>
-#include <gst/base/gstcollectpads2.h>
+#include <gst/base/gstcollectpads.h>
#include <gst/riff/riff-media.h>
#include "gstasfobjects.h"
@@ -57,7 +57,7 @@ enum _GstAsfMuxState
struct _GstAsfPad
{
- GstCollectData2 collect;
+ GstCollectData collect;
gboolean is_audio;
guint8 stream_number;
@@ -143,7 +143,7 @@ struct _GstAsfMux
/* pads */
GstPad *srcpad;
- GstCollectPads2 *collect;
+ GstCollectPads *collect;
GstPadEventFunction collect_event;
};
diff --git a/gst/asfmux/gstasfobjects.h b/gst/asfmux/gstasfobjects.h
index 00546fff4..2a91a4c79 100644
--- a/gst/asfmux/gstasfobjects.h
+++ b/gst/asfmux/gstasfobjects.h
@@ -22,7 +22,7 @@
#include <glib.h>
#include <gst/gst.h>
#include <gst/base/gstbytereader.h>
-#include <gst/base/gstcollectpads2.h>
+#include <gst/base/gstcollectpads.h>
#define ASF_PAYLOAD_IS_KEYFRAME(pay) ((pay->stream_number & 0x80) != 0)
#define ASF_MILI_TO_100NANO(v) (v * 10000)
@@ -75,7 +75,7 @@ typedef struct _AsfPayload
guint32 presentation_time;
GstBuffer *data;
- GstCollectData2 *pad;
+ GstCollectData *pad;
/* simple index info */
gboolean has_packet_info;
diff --git a/gst/asfmux/gstasfmux.c b/gst/asfmux/gstasfmux.c
index e7184f601..d43ae39b2 100644
--- a/gst/asfmux/gstasfmux.c
+++ b/gst/asfmux/gstasfmux.c
@@ -335,9 +335,9 @@ gst_asf_mux_init (GstAsfMux * asfmux)
gst_pad_use_fixed_caps (asfmux->srcpad);
gst_element_add_pad (GST_ELEMENT (asfmux), asfmux->srcpad);
- asfmux->collect = gst_collect_pads2_new ();
- gst_collect_pads2_set_function (asfmux->collect,
- (GstCollectPads2Function) GST_DEBUG_FUNCPTR (gst_asf_mux_collected),
+ asfmux->collect = gst_collect_pads_new ();
+ gst_collect_pads_set_function (asfmux->collect,
+ (GstCollectPadsFunction) GST_DEBUG_FUNCPTR (gst_asf_mux_collected),
asfmux);
asfmux->payloads = NULL;
@@ -1851,7 +1851,7 @@ gst_asf_mux_process_buffer (GstAsfMux * asfmux, GstAsfPad * pad,
AsfPayload *payload;
payload = g_malloc0 (sizeof (AsfPayload));
- payload->pad = (GstCollectData2 *) pad;
+ payload->pad = (GstCollectData *) pad;
payload->data = buf;
GST_LOG_OBJECT (asfmux,
@@ -1911,7 +1911,7 @@ gst_asf_mux_process_buffer (GstAsfMux * asfmux, GstAsfPad * pad,
}
static GstFlowReturn
-gst_asf_mux_collected (GstCollectPads2 * collect, gpointer data)
+gst_asf_mux_collected (GstCollectPads * collect, gpointer data)
{
GstAsfMux *asfmux = GST_ASF_MUX_CAST (data);
GstFlowReturn ret = GST_FLOW_OK;
@@ -1937,15 +1937,15 @@ gst_asf_mux_collected (GstCollectPads2 * collect, gpointer data)
walk = asfmux->collect->data;
while (walk) {
GstAsfPad *pad;
- GstCollectData2 *data;
+ GstCollectData *data;
GstClockTime time;
- data = (GstCollectData2 *) walk->data;
+ data = (GstCollectData *) walk->data;
pad = (GstAsfPad *) data;
walk = g_slist_next (walk);
- buf = gst_collect_pads2_peek (collect, data);
+ buf = gst_collect_pads_peek (collect, data);
if (buf == NULL) {
GST_LOG_OBJECT (asfmux, "Pad %s has no buffers",
GST_PAD_NAME (pad->collect.pad));
@@ -1980,7 +1980,7 @@ gst_asf_mux_collected (GstCollectPads2 * collect, gpointer data)
/* we have data */
GST_LOG_OBJECT (asfmux, "selected pad %s with time %" GST_TIME_FORMAT,
GST_PAD_NAME (best_pad->collect.pad), GST_TIME_ARGS (best_time));
- buf = gst_collect_pads2_pop (collect, &best_pad->collect);
+ buf = gst_collect_pads_pop (collect, &best_pad->collect);
ret = gst_asf_mux_process_buffer (asfmux, best_pad, buf);
} else {
/* no data, let's finish it up */
@@ -2279,8 +2279,8 @@ gst_asf_mux_request_new_pad (GstElement * element,
collect_size = sizeof (GstAsfVideoPad);
}
collect_pad = (GstAsfPad *)
- gst_collect_pads2_add_pad_full (asfmux->collect, newpad, collect_size,
- (GstCollectData2DestroyNotify) (gst_asf_mux_pad_reset), TRUE);
+ gst_collect_pads_add_pad_full (asfmux->collect, newpad, collect_size,
+ (GstCollectDataDestroyNotify) (gst_asf_mux_pad_reset), TRUE);
/* set up pad */
collect_pad->is_audio = is_audio;
@@ -2294,7 +2294,7 @@ gst_asf_mux_request_new_pad (GstElement * element,
collect_pad->stream_number = asfmux->stream_number;
/* FIXME: hacked way to override/extend the event function of
* GstCollectPads2; because it sets its own event function giving
* the element no access to events.
*/
asfmux->collect_event = (GstPadEventFunction) GST_PAD_EVENTFUNC (newpad);
@@ -2391,12 +2391,12 @@ gst_asf_mux_change_state (GstElement * element, GstStateChange transition)
asfmux->packet_size = asfmux->prop_packet_size;
asfmux->preroll = asfmux->prop_preroll;
asfmux->merge_stream_tags = asfmux->prop_merge_stream_tags;
- gst_collect_pads2_start (asfmux->collect);
+ gst_collect_pads_start (asfmux->collect);
break;
case GST_STATE_CHANGE_PAUSED_TO_PLAYING:
break;
case GST_STATE_CHANGE_PAUSED_TO_READY:
- gst_collect_pads2_stop (asfmux->collect);
+ gst_collect_pads_stop (asfmux->collect);
asfmux->state = GST_ASF_MUX_STATE_NONE;
break;
default:
@@ -2294,7 +2294,7 @@ gst_asf_mux_request_new_pad (GstElement * element,
collect_pad->stream_number = asfmux->stream_number;
/* FIXME: hacked way to override/extend the event function of
- * GstCollectPads2; because it sets its own event function giving
+ * GstCollectPads; because it sets its own event function giving
* the element no access to events.
*/